#[non_exhaustive]pub enum SecretResolutionError {
UnsupportedReference {
provider: &'static str,
},
EnvVar {
name: String,
source: VarError,
},
Provider {
message: String,
source: Option<Box<dyn Error + Send + Sync>>,
},
}Expand description
Errors raised by a secret provider while resolving a reference.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
UnsupportedReference
The reference names a provider this resolver does not support.
EnvVar
An environment-variable lookup failed.
Provider
A provider-specific resolver failure.